function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
import { Lut } from "@aics/volume-viewer";
import { useEffect } from "react";
import { controlPointsToLut, rampToControlPoints } from "../../shared/utils/controlPointsToLut";
/**
 * A component that doesn't render anything, but reacts to the provided `ChannelState`
 * and keeps it in sync with the viewer.
 */
var ChannelUpdater = function ChannelUpdater(_ref) {
  var index = _ref.index,
    channelState = _ref.channelState,
    view3d = _ref.view3d,
    image = _ref.image,
    version = _ref.version;
  var volumeEnabled = channelState.volumeEnabled,
    isosurfaceEnabled = channelState.isosurfaceEnabled,
    isovalue = channelState.isovalue,
    colorizeEnabled = channelState.colorizeEnabled,
    colorizeAlpha = channelState.colorizeAlpha,
    opacity = channelState.opacity,
    color = channelState.color;

  // Effects to update channel settings should check if image is present and channel is loaded first
  var useImageEffect = function useImageEffect(effect, deps) {
    useEffect(function () {
      if (image && version > 0) {
        return effect(image);
      }
    }, [].concat(_toConsumableArray(deps), [image, version]));
  };

  // enable/disable channel can't be dependent on channel load state because it may trigger the channel to load
  useEffect(function () {
    if (image) {
      view3d.setVolumeChannelEnabled(image, index, volumeEnabled);
      view3d.updateLuts(image);
    }
  }, [image, volumeEnabled]);
  useEffect(function () {
    if (image) {
      view3d.setVolumeChannelOptions(image, index, {
        isosurfaceEnabled: isosurfaceEnabled
      });
    }
  }, [image, isosurfaceEnabled]);
  useImageEffect(function (currentImage) {
    return view3d.setVolumeChannelOptions(currentImage, index, {
      isovalue: isovalue
    });
  }, [isovalue]);
  useImageEffect(function (currentImage) {
    return view3d.setVolumeChannelOptions(currentImage, index, {
      isosurfaceOpacity: opacity
    });
  }, [opacity]);
  useImageEffect(function (currentImage) {
    view3d.setVolumeChannelOptions(currentImage, index, {
      color: color
    });
    view3d.updateLuts(currentImage);
  }, [color]);
  var controlPoints = channelState.controlPoints,
    ramp = channelState.ramp,
    useControlPoints = channelState.useControlPoints;
  useImageEffect(function (currentImage) {
    if (useControlPoints && controlPoints.length < 2) {
      return;
    }
    var controlPointsToUse = useControlPoints ? controlPoints : rampToControlPoints(ramp);
    var gradient = controlPointsToLut(controlPointsToUse);
    currentImage.setLut(index, gradient);
    view3d.updateLuts(currentImage);
  }, [controlPoints, ramp, useControlPoints]);
  useImageEffect(function (currentImage) {
    if (colorizeEnabled) {
      // TODO get the labelColors from the tf editor component
      var lut = new Lut().createLabelColors(currentImage.getHistogram(index));
      currentImage.setColorPalette(index, lut.lut);
      currentImage.setColorPaletteAlpha(index, colorizeAlpha);
    } else {
      currentImage.setColorPaletteAlpha(index, 0);
    }
    view3d.updateLuts(currentImage);
  }, [colorizeEnabled]);
  useImageEffect(function (currentImage) {
    currentImage.setColorPaletteAlpha(index, colorizeEnabled ? colorizeAlpha : 0);
    view3d.updateLuts(currentImage);
  }, [colorizeAlpha]);
  return null;
};
export default ChannelUpdater;