import { describe, expect, it } from "@jest/globals";
import { matchChannel, makeChannelIndexGrouping } from "../viewerChannelSettings";
describe("viewer settings", function () {
  describe("matching names", function () {
    it.each([["test1", [true, false, false]], ["test", [true, true, true]], ["^test$", [false, false, false]], ["1|2", [true, true, false]], [1, [false, true, false]]])("matches against %p", function (re, expected) {
      var channelNames = ["test1", "test2", "test3"];
      var setting = {
        match: re
      };
      var result = channelNames.map(function (ch, i) {
        return matchChannel(ch, i, setting);
      });
      expect(result).toEqual(expected);
    });
  });
  describe("grouping channels", function () {
    it("groups channels into their named groups when all match", function () {
      var channelNames = ["test1", "test2", "test3"];
      var settings = {
        groups: [{
          name: "1",
          channels: [{
            match: "2"
          }]
        }, {
          name: "2",
          channels: [{
            match: "3"
          }]
        }, {
          name: "3",
          channels: [{
            match: "1"
          }]
        }],
        maskChannelName: ""
      };
      var expected = {
        "1": [1],
        "2": [2],
        "3": [0]
      };
      var result = makeChannelIndexGrouping(channelNames, settings);
      expect(Object.keys(result).length).toBe(3);
      for (var i in result) {
        expect(result[i].length).toBe(1);
        expect(result[i]).toEqual(expected[i]);
      }
    });
    it('groups channels into group "Other" when none match', function () {
      var channelNames = ["test1", "test2", "test3"];
      var settings = {
        groups: [{
          name: "1",
          channels: [{
            match: "z"
          }]
        }, {
          name: "2",
          channels: [{
            match: "y"
          }]
        }, {
          name: "3",
          channels: [{
            match: "x"
          }]
        }],
        maskChannelName: ""
      };
      var expected = {
        "1": [],
        "2": [],
        "3": [],
        Other: [0, 1, 2]
      };
      var result = makeChannelIndexGrouping(channelNames, settings);
      expect(Object.keys(result).length).toBe(4);
      for (var i in result) {
        expect(result[i]).toEqual(expected[i]);
      }
    });
    it('groups channels into named groups and "Other" when only some match', function () {
      var channelNames = ["test1", "test2", "test3"];
      var settings = {
        groups: [{
          name: "1",
          channels: [{
            match: "1"
          }]
        }, {
          name: "2",
          channels: [{
            match: "2"
          }]
        }, {
          name: "3",
          channels: [{
            match: "x"
          }]
        }],
        maskChannelName: ""
      };
      var expected = {
        "1": [0],
        "2": [1],
        "3": [],
        Other: [2]
      };
      var result = makeChannelIndexGrouping(channelNames, settings);
      expect(Object.keys(result).length).toBe(4);
      for (var i in result) {
        expect(result[i]).toEqual(expected[i]);
      }
    });
    it('groups all channels into group "Channels" when no groups are given', function () {
      var channelNames = ["test1", "test2", "test3"];
      var settings = {
        groups: [],
        maskChannelName: ""
      };
      var expected = {
        Channels: [0, 1, 2]
      };
      var result = makeChannelIndexGrouping(channelNames, settings);
      expect(Object.keys(result).length).toBe(1);
      for (var i in result) {
        expect(result[i]).toEqual(expected[i]);
      }
    });
  });
});