import { getDefaultChannelState } from "../constants";
import { findFirstChannelMatch, getDisplayName } from "./viewerChannelSettings";

/** Sets all fields of the viewer state to the values of the `newState`. */
export function overrideViewerState(changeViewerSetting, newState) {
  for (var _i = 0, _arr = Object.keys(newState); _i < _arr.length; _i++) {
    var key = _arr[_i];
    changeViewerSetting(key, newState[key]);
  }

  // Pathtrace rendering is not allowed in 2D view mode but is in 3D mode.
  // Since we're not guaranteed on the order of object keys, apply changes to render mode a second time
  // in case we were previously in 2D view mode and the change was blocked, but we're now in 3D.
  changeViewerSetting("renderMode", newState.renderMode);
}
export function overrideChannelStates(setChannelSettings, currentStates, newStates) {
  // Match the names in the new state with the existing state so we do not override the names.
  // Also don't reset the control points or ramps, since these will be reset in the app.
  for (var i = 0; i < newStates.length; i++) {
    newStates[i].name = currentStates[i].name;
    newStates[i].controlPoints = currentStates[i].controlPoints;
    newStates[i].ramp = currentStates[i].ramp;
  }
  setChannelSettings(newStates);
}

/** Returns the indices of channels that have either the volume or isosurface enabled. */
export function getEnabledChannelIndices(channelSettings) {
  var enabledChannels = [];
  for (var i = 0; i < channelSettings.length; i++) {
    if (channelSettings[i].volumeEnabled || channelSettings[i].isosurfaceEnabled) {
      enabledChannels.push(i);
    }
  }
  return enabledChannels;
}
export function colorHexToArray(hex) {
  // hex is a xxxxxx string. split it into array of rgb ints
  var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
  if (result) {
    return [parseInt(result[1], 16), parseInt(result[2], 16), parseInt(result[3], 16)];
  } else {
    return null;
  }
}
export function initializeOneChannelSetting(channelName, index, defaultColor, viewerChannelSettings) {
  var _initSettings$enabled, _initSettings$surface, _initSettings$coloriz, _initSettings$coloriz2, _initSettings$isovalu, _initSettings$surface2, _colorHexToArray, _initSettings$color, _initSettings$control, _initSettings$control2, _initSettings$ramp;
  var defaultChannelState = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : getDefaultChannelState();
  var initSettings = {};
  if (viewerChannelSettings) {
    var _findFirstChannelMatc;
    // search for channel in settings using groups, names and match values
    initSettings = (_findFirstChannelMatc = findFirstChannelMatch(channelName, index, viewerChannelSettings)) !== null && _findFirstChannelMatc !== void 0 ? _findFirstChannelMatc : {};
  }
  return {
    name: channelName !== null && channelName !== void 0 ? channelName : "Channel " + index,
    displayName: getDisplayName(channelName !== null && channelName !== void 0 ? channelName : "Channel " + index, index, viewerChannelSettings),
    volumeEnabled: (_initSettings$enabled = initSettings.enabled) !== null && _initSettings$enabled !== void 0 ? _initSettings$enabled : defaultChannelState.volumeEnabled,
    isosurfaceEnabled: (_initSettings$surface = initSettings.surfaceEnabled) !== null && _initSettings$surface !== void 0 ? _initSettings$surface : defaultChannelState.isosurfaceEnabled,
    colorizeEnabled: (_initSettings$coloriz = initSettings.colorizeEnabled) !== null && _initSettings$coloriz !== void 0 ? _initSettings$coloriz : defaultChannelState.colorizeEnabled,
    colorizeAlpha: (_initSettings$coloriz2 = initSettings.colorizeAlpha) !== null && _initSettings$coloriz2 !== void 0 ? _initSettings$coloriz2 : defaultChannelState.colorizeAlpha,
    isovalue: (_initSettings$isovalu = initSettings.isovalue) !== null && _initSettings$isovalu !== void 0 ? _initSettings$isovalu : defaultChannelState.isovalue,
    opacity: (_initSettings$surface2 = initSettings.surfaceOpacity) !== null && _initSettings$surface2 !== void 0 ? _initSettings$surface2 : defaultChannelState.opacity,
    color: (_colorHexToArray = colorHexToArray((_initSettings$color = initSettings.color) !== null && _initSettings$color !== void 0 ? _initSettings$color : "")) !== null && _colorHexToArray !== void 0 ? _colorHexToArray : defaultColor,
    useControlPoints: (_initSettings$control = initSettings.controlPointsEnabled) !== null && _initSettings$control !== void 0 ? _initSettings$control : defaultChannelState.useControlPoints,
    controlPoints: (_initSettings$control2 = initSettings.controlPoints) !== null && _initSettings$control2 !== void 0 ? _initSettings$control2 : defaultChannelState.controlPoints,
    ramp: (_initSettings$ramp = initSettings.ramp) !== null && _initSettings$ramp !== void 0 ? _initSettings$ramp : defaultChannelState.ramp
  };
}