import type { RawArrayData, RawArrayInfo, View3d, Volume } from "@aics/volume-viewer";
import { MutableRefObject } from "react";
import type { MetadataRecord } from "../../shared/types";
import type { ViewerChannelSettings } from "../../shared/utils/viewerChannelSettings";
import type { ViewerState } from "../ViewerStateProvider/types";
/** `typeof useEffect`, but the effect handler takes a `Volume` as an argument */
export type UseImageEffectType = (effect: (image: Volume) => void | (() => void), deps: React.DependencyList) => void;
type ControlNames = "alphaMaskSlider" | "autoRotateButton" | "axisClipSliders" | "brightnessSlider" | "backgroundColorPicker" | "boundingBoxColorPicker" | "colorPresetsDropdown" | "densitySlider" | "levelsSliders" | "interpolationControl" | "saveSurfaceButtons" | "fovCellSwitchControls" | "viewModeRadioButtons" | "resetCameraButton" | "showAxesButton" | "showBoundingBoxButton" | "metadataViewer";
/** Show/hide different elements of the UI */
export type ControlVisibilityFlags = {
    [K in ControlNames]: boolean;
};
export interface AppProps {
    rawData?: RawArrayData;
    rawDims?: RawArrayInfo;
    imageUrl: string | string[];
    parentImageUrl?: string | string[];
    viewerChannelSettings?: ViewerChannelSettings;
    appHeight: string;
    cellId: string;
    visibleControls?: Partial<ControlVisibilityFlags>;
    viewerSettings?: Partial<ViewerState>;
    imageDownloadHref: string;
    parentImageDownloadHref: string;
    pixelSize?: [number, number, number];
    canvasMargin: string;
    transform?: {
        translation: [number, number, number];
        rotation: [number, number, number];
    };
    metadata?: MetadataRecord;
    view3dRef?: MutableRefObject<View3d | null>;
    metadataFormatter?: (metadata: MetadataRecord) => MetadataRecord;
    onControlPanelToggle?: (collapsed: boolean) => void;
}
export {};
