/// <reference types="react" />
import { ViewerState, ViewerStateContextType, ResetState } from "./types";
import { ViewerChannelSettings } from "../../shared/utils/viewerChannelSettings";
/**
 * Provides reset functionality for the viewer and channel states.
 */
export default class ResetStateProvider implements ResetState {
    savedViewerState: Partial<ViewerState>;
    savedViewerChannelSettings: ViewerChannelSettings | undefined;
    useDefaultViewerChannelSettings: boolean;
    channelsToReset: Set<number>;
    channelsToResetOnLoad: Set<number>;
    ref: React.MutableRefObject<ViewerStateContextType>;
    constructor(viewerStateRef: React.MutableRefObject<ViewerStateContextType>);
    setSavedViewerState(state: Partial<ViewerState>): void;
    setSavedViewerChannelSettings(settings: ViewerChannelSettings | undefined): void;
    getChannelsAwaitingReset(): Set<number>;
    getChannelsAwaitingResetOnLoad(): Set<number>;
    onResetChannel(channelIndex: number): void;
    /**
     * Returns the current viewer channel settings that the viewer should use when
     * resetting channels to an initial state.
     */
    getCurrentViewerChannelSettings(): ViewerChannelSettings | undefined;
    /**
     * Helper method. Resets the viewer and all channels to the provided state. If new data needs to
     * be loaded, handles setup so the reset will be applied to each channel as it loads in.
     */
    private resetToState;
    /** Resets to the initial saved state of the viewer, as shown to the user on load. */
    resetToSavedViewerState(): void;
    /** Reset to global default viewer state, as if loading the volume with no parameters. */
    resetToDefaultViewerState(): void;
}
