import { CameraState } from "@aics/volume-viewer";
import { ChannelState, ViewerState } from "../components/ViewerStateProvider/types";
import { ViewMode } from "./enums";
import { ColorArray } from "./utils/colorRepresentations";
import { ViewerChannelSettings } from "./utils/viewerChannelSettings";
export declare const // Control panel will automatically close if viewport is less than this width
CONTROL_PANEL_CLOSE_WIDTH = 970, BACKGROUND_COLOR_DEFAULT: ColorArray, BOUNDING_BOX_COLOR_DEFAULT: ColorArray, AXIS_MARGIN_DEFAULT: [number, number], SCALE_BAR_MARGIN_DEFAULT: [number, number], LUT_MIN_PERCENTILE = 0.5, LUT_MAX_PERCENTILE = 0.983, ISOSURFACE_OPACITY_SLIDER_MAX = 255, ALPHA_MASK_SLIDER_DEFAULT = 0, BRIGHTNESS_SLIDER_LEVEL_DEFAULT = 70, DENSITY_SLIDER_LEVEL_DEFAULT = 50, LEVELS_SLIDER_DEFAULT: ColorArray, INTERPOLATION_ENABLED_DEFAULT = true, OTHER_CHANNEL_KEY = "Other", SINGLE_GROUP_CHANNEL_KEY = "Channels";
export declare const TFEDITOR_DEFAULT_COLOR: ColorArray;
export declare const TFEDITOR_MAX_BIN = 255;
export declare const CACHE_MAX_SIZE = 1000000000;
export declare const QUEUE_MAX_SIZE = 10;
export declare const QUEUE_MAX_LOW_PRIORITY_SIZE = 4;
export declare const PRESET_COLORS_1: ColorArray[];
export declare const PRESET_COLORS_2: ColorArray[];
export declare const PRESET_COLORS_3: ColorArray[];
export declare const PRESET_COLORS_0: ColorArray[];
export declare const PRESET_COLOR_MAP: readonly {
    colors: ColorArray[];
    name: string;
}[];
/**
 * Reflects the default camera settings the 3D viewer uses on volume load.
 * These SHOULD NOT be changed; otherwise, existing shared links that don't specify the
 * camera settings will use the new defaults and may be in unexpected orientations or positions.
 */
export declare const getDefaultCameraState: (viewMode?: ViewMode) => CameraState;
export declare const getDefaultViewerChannelSettings: () => ViewerChannelSettings;
/**
 * Returns the default viewer state as a new object.
 */
export declare const getDefaultViewerState: () => ViewerState;
/** Returns the default color for a channel, by its index. */
export declare function getDefaultChannelColor(channelIndex: number): ColorArray;
/**
 * Returns the default channel state as a new object. If an index is provided, uses the default
 * color preset for that index.
 * @param index Optional channel index to use for the color preset.
 * @returns a default ChannelState object.
 */
export declare const getDefaultChannelState: (index?: number) => ChannelState;
