import { MutableRefObject } from "react";
/** A `useState` that also creates a getter function for breaking through closures. */
export declare function useStateWithGetter<T>(initialState: T | (() => T)): [T, (value: T) => void, () => T];
/**
 * Wraps a setter function and keeps a ref updated to follow the set value. Useful for making the most up-to-date value
 * of some state accessible to a closure that might be called after the value is updated.
 */
export declare function useRefWithSetter<T>(setter: (value: T) => void): [MutableRefObject<T | undefined>, (value: T) => void];
export declare function useRefWithSetter<T>(setter: (value: T) => void, init: T): [MutableRefObject<T>, (value: T) => void];
/**
 * For objects which are persistent for the lifetime of the component, not
 * a member of state, and require a constructor to create. Wraps `useRef`.
 */
export declare function useConstructor<T>(constructor: () => T): T;
