import { ControlPoint } from "@aics/volume-viewer";
/** Settings for a single channel, as passed in via props by App users */
export interface ViewerChannelSetting {
    match: (string | number)[] | string | number;
    name?: string;
    color?: string;
    enabled?: boolean;
    surfaceEnabled?: boolean;
    /**
     * Min and max values for the intensity lookup table, which maps from raw intensity values
     * in the volume to opacity and color. Defaults to [0, 255].
     *
     * - Plain numbers are treated as direct intensity values.
     * - `p{n}` represents a percentile, where `n` is a percentile in the [0, 100] range.
     * - `m{n}` represents the median multiplied by `n / 100`.
     * - `autoij` in either the min or max fields will use the "auto" algorithm
     * from ImageJ to select the min and max.
     */
    lut?: [string, string];
    /**
     * Whether to show control point controls instead of a simpler ramp control.
     * Defaults to false.
     */
    controlPointsEnabled?: boolean;
    controlPoints?: ControlPoint[];
    ramp?: [number, number];
    isovalue?: number;
    surfaceOpacity?: number;
    colorizeEnabled?: boolean;
    colorizeAlpha?: number;
}
export interface ViewerChannelGroup {
    name: string;
    channels: ViewerChannelSetting[];
}
export interface ViewerChannelSettings {
    maskChannelName?: string;
    groups: ViewerChannelGroup[];
}
export type ChannelGrouping = {
    [key: string]: number[];
};
export declare function matchChannel(channelName: string, channelIndex: number, c: ViewerChannelSetting): boolean;
export declare function findFirstChannelMatch(channel: string, channelIndex: number, settings: ViewerChannelSettings): ViewerChannelSetting | undefined;
export declare function getDisplayName(name: string, index: number, settings?: ViewerChannelSettings): string;
export declare function makeChannelIndexGrouping(channels: string[], settings?: ViewerChannelSettings): ChannelGrouping;
